@@ -15,14 +15,14 @@ sys.path.insert(0, parentdir)
 
 try:
     from skodaconnect import Connection
-except ModuleNotFoundError:
-    print("Unable to import library")
+except ModuleNotFoundError as e:
+    print(f"Unable to import library: {e}")
     sys.exit(1)
 
 logging.basicConfig(level=logging.DEBUG)
 
-USERNAME = 'email@domain.com'
-PASSWORD = 'password!'
+USERNAME = 'faekie@hotmail.com'
+PASSWORD = 'VinterStorm2021!'
 PRINTRESPONSE = True
 INTERVAL = 20
 
@@ -35,14 +35,15 @@ COMPONENTS = {
 }
 
 RESOURCES = [
-		"adblue_level",
-		"auxiliary_climatisation",
-		"battery_level",
-		"charge_max_ampere",
-		"charger_action_status",
-		"charging",
-                "charge_rate",
-                "charging_power",
+        "adblue_level",
+	"auxiliary_climatisation",
+	"battery_level",
+        "min_charge_level",
+	"charge_max_ampere",
+	"charger_action_status",
+        "charging",
+        "charge_rate",
+        "charging_power",
 		"charging_cable_connected",
 		"charging_cable_locked",
 		"charging_time_left",
@@ -51,9 +52,9 @@ RESOURCES = [
 		"climatisation_without_external_power",
 		"combined_range",
 		"combustion_range",
-                "departure1",
-                "departure2",
-                "departure3",
+        "departure1",
+        "departure2",
+        "departure3",
 		"distance",
 		"door_closed_left_back",
 		"door_closed_left_front",
@@ -79,6 +80,8 @@ RESOURCES = [
 		"position",
 		"refresh_action_status",
 		"refresh_data",
+        "request_flash",
+        "request_honkandflash",
 		"request_in_progress",
 		"request_results",
 		"requests_remaining",
@@ -103,7 +106,7 @@ RESOURCES = [
 		"window_closed_right_front",
 		"window_heater",
 		"windows_closed",
-                "seat_heating"
+        "seat_heating"
 ]
 
 def is_enabled(attr):
@@ -124,6 +127,8 @@ async def main():
         if await connection.doLogin():
             print('Login success!')
             print(datetime.now())
+            print('Fetching vehicles associated with account.')
+            await connection.get_vehicles()
 
             instruments = set()
             for vehicle in connection.vehicles:
@@ -148,6 +153,7 @@ async def main():
                 print(f"\tVIN: {vehicle.vin}")
                 print(f"\tModel: {vehicle.model}")
                 print(f"\tManufactured: {vehicle.model_year}")
+                print(f"\tModel image: {vehicle.model_image}")
                 print(f"\tConnect service deactivated: {vehicle.deactivated}")
                 if vehicle.is_nickname_supported: print(f"\tNickname: {vehicle.nickname}")
                 print(f"\tObject attributes, and methods:")
@@ -168,23 +174,36 @@ async def main():
         print('########################################')
         print('#      Instruments from dashboard      #')
         print('########################################')
-        for instrument in instruments:
+        inst_list = sorted(instruments, key=lambda x: x.attr)
+        for instrument in inst_list:
             print(f'{instrument.full_name} - ({instrument.attr})')
             print(f'\tstr_state: {instrument.str_state} - state: {instrument.state}')
             print(f'\tattributes: {instrument.attributes}')
             print("")
 
-        # Sleep for a given ammount of time and update all vehicles
         print('')
         print(f"Sleeping for {INTERVAL} seconds")
+        #data = {
+        #    'performAction': {
+        #        'quickstop': {
+        #            'active': False
+        #        }
+        #    }
+        #}
+        #spin = 1234
+        data = {'type': 'stop'}
+        resp = await connection.setCharging("TMBJW7NP0L7050944", data=data)
+        print(resp)
         time.sleep(INTERVAL)
 
+        print('')
+        print(datetime.now())
         print('')
         print('########################################')
         print('#    Updating all values from Skoda    #')
         print('########################################')
         print("Updating ALL values from Skoda Connect...")
-        if await connection.update():
+        if await connection.update_all():
             print("Success!")
         else:
             print("Failed")
@@ -197,6 +216,8 @@ async def main():
         for vehicle in connection.vehicles:
             txt = vehicle.vin
             print('')
+            print(datetime.now())
+            print('')
             print('########################################')
             print('#          Update charger data         #')
             print(txt.center(40, '#'))
