@@ -2,6 +2,7 @@
 # Thanks to molobrakos
 
 import logging
+from datetime import datetime
 from skodaconnect.utilities import camel2slug
 
 _LOGGER = logging.getLogger(__name__)
@@ -28,10 +29,10 @@ class Instrument:
     def setup(self, vehicle, **config):
         self.vehicle = vehicle
         if not self.is_supported:
-            _LOGGER.debug("%s (%s:%s) is not supported", self, type(self).__name__, self.attr)
+            _LOGGER.debug(f"{self} ({type(self).__name__}:{self.attr}) is not supported")
             return False
 
-        _LOGGER.debug("%s is supported", self)
+        _LOGGER.debug(f"{self} is supported")
         self.configurate(**config)
         return True
 
@@ -41,7 +42,7 @@ class Instrument:
 
     @property
     def full_name(self):
-        return "%s %s" % (self.vehicle_name, self.name)
+        return f"{self.vehicle_name} {self.name}"
 
     @property
     def is_mutable(self):
@@ -78,8 +79,8 @@ class Sensor(Instrument):
         self.unit = unit
         self.convert = False
 
-    def configurate(self, miles=False, **config):
-        if self.unit and miles:
+    def configurate(self, **config):
+        if self.unit and config.get('miles', False) is True:
             if "km" == self.unit:
                 self.unit = "mi"
                 self.convert = True
@@ -92,6 +93,15 @@ class Sensor(Instrument):
             elif "kWh/100 km" == self.unit:
                 self.unit = "kWh/100 mi"
                 self.convert = True
+        elif self.unit and config.get('scandinavian_miles', False) is True:
+            if "km" == self.unit:
+                self.unit = "mil"
+            elif "km/h" == self.unit:
+                self.unit = "mil/h"
+            elif "l/100 km" == self.unit:
+                self.unit = "l/100 mil"
+            elif "kWh/100 km" == self.unit:
+                self.unit = "kWh/100 mil"
 
         # Init placeholder for parking heater duration
         config.get('parkingheater', 30)
@@ -124,6 +134,8 @@ class Sensor(Instrument):
         elif val and self.unit and "°F" in self.unit and self.convert is True:
             temp = round((val * 9 / 5) + 32, 1)
             return temp
+        elif val and self.unit in ['mil', 'mil/h']:
+            return val / 10
         else:
             return val
 
@@ -149,7 +161,7 @@ class BinarySensor(Instrument):
         if self.device_class == "plug":
             return "Connected" if self.state else "Disconnected"
         if self.state is None:
-            _LOGGER.error("Can not encode state %s:%s", self.attr, self.state)
+            _LOGGER.error(f"Can not encode state {self.attr} {self.state}")
             return "?"
         return "On" if self.state else "Off"
 
@@ -288,10 +300,16 @@ class Position(Instrument):
     def str_state(self):
         state = super().state #or {}
         ts = state.get("timestamp", None)
+        if isinstance(ts, str):
+            time = str(datetime.strptime(ts,'%Y-%m-%dT%H:%M:%SZ').astimezone(tz=None))
+        elif isinstance(ts, datetime):
+            time = str(ts.astimezone(tz=None))
+        else:
+            time = None
         return (
             state.get("lat", "?"),
             state.get("lng", "?"),
-            str(ts.astimezone(tz=None)) if ts else None,
+            time,
         )
 
 
@@ -326,7 +344,7 @@ class DoorLock(Instrument):
                 self.callback()
             return response
         except Exception as e:
-            _LOGGER.error("Lock failed: %", e.args[0])
+            _LOGGER.error(f"Lock failed: {e}")
             return False
 
     async def unlock(self):
@@ -337,7 +355,7 @@ class DoorLock(Instrument):
                 self.callback()
             return response
         except Exception as e:
-            _LOGGER.error("Unlock failed: %", e.args[0])
+            _LOGGER.error(f"Unlock failed: {e}")
             return False
 
     @property
@@ -372,6 +390,57 @@ class TrunkLock(Instrument):
         return None
 
 # Switches
+class RequestHonkAndFlash(Switch):
+    def __init__(self):
+        super().__init__(attr="request_honkandflash", name="Start honking and flashing", icon="mdi:car-emergency")
+
+    @property
+    def state(self):
+        return self.vehicle.request_honkandflash
+
+    async def turn_on(self):
+        await self.vehicle.set_honkandflash('honkandflash')
+        await self.vehicle.update()
+        if self.callback is not None:
+            self.callback()
+
+    async def turn_off(self):
+        pass
+
+    @property
+    def assumed_state(self):
+        return False
+
+    @property
+    def attributes(self):
+        return dict(last_result = self.vehicle.honkandflash_action_status)
+
+
+class RequestFlash(Switch):
+    def __init__(self):
+        super().__init__(attr="request_flash", name="Start flashing", icon="mdi:car-parking-lights")
+
+    @property
+    def state(self):
+        return self.vehicle.request_flash
+
+    async def turn_on(self):
+        await self.vehicle.set_honkandflash('flash')
+        await self.vehicle.update()
+        if self.callback is not None:
+            self.callback()
+
+    async def turn_off(self):
+        pass
+
+    @property
+    def assumed_state(self):
+        return False
+
+    @property
+    def attributes(self):
+        return dict(last_result = self.vehicle.honkandflash_action_status)
+
 
 class RequestUpdate(Switch):
     def __init__(self):
@@ -731,6 +800,8 @@ def create_instruments():
         Position(),
         DoorLock(),
         TrunkLock(),
+        RequestFlash(),
+        RequestHonkAndFlash(),
         RequestUpdate(),
         WindowHeater(),
         SeatHeating(),
@@ -758,6 +829,12 @@ def create_instruments():
             icon="mdi:battery",
             unit="%",
         ),
+        Sensor(
+            attr="min_charge_level",
+            name="Minimum charge level",
+            icon="mdi:battery-positive",
+            unit="%",
+        ),
         Sensor(
             attr="adblue_level",
             name="Adblue level",
